@@ -1,6 +1,6 @@
 package App::EvalServerAdvanced;
 
-our $VERSION = 0.014;
+our $VERSION = '0.015';
 
 use strict;
 use App::EvalServerAdvanced::Sandbox;
@@ -12,6 +12,7 @@ use App::EvalServerAdvanced::JobManager;
 use Function::Parameters;
 use App::EvalServerAdvanced::Protocol;
 use App::EvalServerAdvanced::Log;
+use Encode;
 
 use Data::Dumper;
 use POSIX qw/_exit/;
@@ -85,9 +86,12 @@ method init() {
               my $prio = ($message->prio->has_pr_deadline ? "deadline" :
                          ($message->prio->has_pr_batch    ? "batch" : "realtime"));
 
+              my $encoding = eval{$message->encoding} // "utf8";
+
               my $evalobj = {
                 files => {map {
-                      ($_->filename => $_->contents)
+                      my $cont = eval {Encode::decode($encoding, $_->contents)} // $_->contents;
+                      ($_->filename => $cont)
                   } $message->{files}->@*},
                 priority => $prio,
                 language => $message->language,
@@ -117,10 +121,10 @@ method init() {
               $future->on_ready(fun ($future) {
                 my $output = eval {$future->get()};
                 if ($@) {
-                  my $response = encode_message(warning => {message => "$@", sequence => $sequence });
+                  my $response = encode_message(warning => {message => Encode::encode($encoding, "$@"), sequence => $sequence });
                   $stream->write($response);
                 } else {
-                  my $response = encode_message(response => {sequence => $sequence, contents => $output});
+                  my $response = encode_message(response => {sequence => $sequence, contents => Encode::encode($encoding, $output)});
                   $stream->write($response);
                 }
 
